@@ -279,8 +279,8 @@ abstract class AbstractDoctrineExtension extends Extension
             }
             $container->fileExists($resource, false);
 
-            if ($container->fileExists($dir.'/'.$this->getMappingObjectDefaultName(), false)) {
-                return $this->detectMappingType($dir, $container);
+            if ($container->fileExists($discoveryPath = $dir.'/'.$this->getMappingObjectDefaultName(), false)) {
+                return $this->detectMappingType($discoveryPath, $container);
             }
 
             return null;
@@ -311,10 +311,16 @@ abstract class AbstractDoctrineExtension extends Extension
         foreach ($glob as $file) {
             $content = file_get_contents($file);
 
-            if (preg_match('/^#\[.*'.$quotedMappingObjectName.'\b/m', $content)) {
+            if (
+                preg_match('/^#\[.*'.$quotedMappingObjectName.'\b/m', $content) ||
+                preg_match('/^#\[.*Embeddable\b/m', $content)
+            ) {
                 break;
             }
-            if (preg_match('/^ \* @.*'.$quotedMappingObjectName.'\b/m', $content)) {
+            if (
+                preg_match('/^ \* @.*'.$quotedMappingObjectName.'\b/m', $content) ||
+                preg_match('/^ \* @.*Embeddable\b/m', $content)
+            ) {
                 $type = 'annotation';
                 break;
             }
