@@ -36,10 +36,13 @@ class AppKernel extends Kernel
         $this->testCase = $testCase;
 
         $fs = new Filesystem();
-        if (!$fs->isAbsolutePath($rootConfig) && !is_file($rootConfig = __DIR__.'/'.$testCase.'/'.$rootConfig)) {
-            throw new \InvalidArgumentException(sprintf('The root config "%s" does not exist.', $rootConfig));
+        foreach ((array) $rootConfig as $config) {
+            if (!$fs->isAbsolutePath($config) && !is_file($config = __DIR__.'/'.$testCase.'/'.$config)) {
+                throw new \InvalidArgumentException(sprintf('The root config "%s" does not exist.', $config));
+            }
+
+            $this->rootConfig[] = $config;
         }
-        $this->rootConfig = $rootConfig;
         $this->authenticatorManagerEnabled = $authenticatorManagerEnabled;
 
         parent::__construct($environment, $debug);
@@ -50,7 +53,7 @@ class AppKernel extends Kernel
      */
     public function getContainerClass(): string
     {
-        return parent::getContainerClass().substr(md5($this->rootConfig.$this->authenticatorManagerEnabled), -16);
+        return parent::getContainerClass().substr(md5(implode('', $this->rootConfig).$this->authenticatorManagerEnabled), -16);
     }
 
     public function registerBundles(): iterable
@@ -79,7 +82,9 @@ class AppKernel extends Kernel
 
     public function registerContainerConfiguration(LoaderInterface $loader)
     {
-        $loader->load($this->rootConfig);
+        foreach ($this->rootConfig as $config) {
+            $loader->load($config);
+        }
 
         if ($this->authenticatorManagerEnabled) {
             $loader->load(function ($container) {
