@@ -18,11 +18,8 @@ use Symfony\Component\HttpKernel\Profiler\Profile;
 use Symfony\Component\HttpKernel\Profiler\Profiler;
 use Twig\Environment;
 use Twig\Loader\LoaderInterface;
-use Twig\Loader\SourceContextLoaderInterface;
 
 /**
- * Test for TemplateManager class.
- *
  * @author Artur Wielogórski <wodor@wodor.net>
  */
 class TemplateManagerTest extends TestCase
@@ -38,7 +35,7 @@ class TemplateManagerTest extends TestCase
     protected $profiler;
 
     /**
-     * @var \Symfony\Bundle\WebProfilerBundle\Profiler\TemplateManager
+     * @var TemplateManager
      */
     protected $templateManager;
 
@@ -46,15 +43,15 @@ class TemplateManagerTest extends TestCase
     {
         parent::setUp();
 
-        $profiler = $this->mockProfiler();
+        $this->profiler = $this->createMock(Profiler::class);
         $twigEnvironment = $this->mockTwigEnvironment();
         $templates = [
-            'data_collector.foo' => ['foo', 'FooBundle:Collector:foo'],
-            'data_collector.bar' => ['bar', 'FooBundle:Collector:bar'],
-            'data_collector.baz' => ['baz', 'FooBundle:Collector:baz'],
+            'data_collector.foo' => ['foo', '@Foo/Collector/foo.html.twig'],
+            'data_collector.bar' => ['bar', '@Foo/Collector/bar.html.twig'],
+            'data_collector.baz' => ['baz', '@Foo/Collector/baz.html.twig'],
         ];
 
-        $this->templateManager = new TemplateManager($profiler, $twigEnvironment, $templates);
+        $this->templateManager = new TemplateManager($this->profiler, $twigEnvironment, $templates);
     }
 
     public function testGetNameOfInvalidTemplate()
@@ -73,7 +70,7 @@ class TemplateManagerTest extends TestCase
             ->withAnyParameters()
             ->willReturnCallback([$this, 'profilerHasCallback']);
 
-        $this->assertEquals('FooBundle:Collector:foo.html.twig', $this->templateManager->getName(new ProfileDummy(), 'foo'));
+        $this->assertEquals('@Foo/Collector/foo.html.twig', $this->templateManager->getName(new ProfileDummy(), 'foo'));
     }
 
     public function profilerHasCallback($panel)
@@ -98,36 +95,20 @@ class TemplateManagerTest extends TestCase
         }
     }
 
-    protected function mockProfile()
-    {
-        return $this->createMock(Profile::class);
-    }
-
     protected function mockTwigEnvironment()
     {
         $this->twigEnvironment = $this->createMock(Environment::class);
 
-        if (Environment::MAJOR_VERSION > 1) {
-            $loader = $this->createMock(LoaderInterface::class);
-            $loader
-                ->expects($this->any())
-                ->method('exists')
-                ->willReturn(true);
-        } else {
-            $loader = $this->createMock(SourceContextLoaderInterface::class);
-        }
+        $loader = $this->createMock(LoaderInterface::class);
+        $loader
+            ->expects($this->any())
+            ->method('exists')
+            ->willReturn(true);
 
         $this->twigEnvironment->expects($this->any())->method('getLoader')->willReturn($loader);
 
         return $this->twigEnvironment;
     }
-
-    protected function mockProfiler()
-    {
-        $this->profiler = $this->createMock(Profiler::class);
-
-        return $this->profiler;
-    }
 }
 
 class ProfileDummy extends Profile
@@ -137,7 +118,7 @@ class ProfileDummy extends Profile
         parent::__construct('token');
     }
 
-    public function hasCollector($name): bool
+    public function hasCollector(string $name): bool
     {
         switch ($name) {
             case 'foo':
