@@ -21,6 +21,7 @@ use Symfony\Component\Console\CommandLoader\FactoryCommandLoader;
 use Symfony\Component\Console\DependencyInjection\AddConsoleCommandPass;
 use Symfony\Component\Console\Event\ConsoleCommandEvent;
 use Symfony\Component\Console\Event\ConsoleErrorEvent;
+use Symfony\Component\Console\Event\ConsoleSignalEvent;
 use Symfony\Component\Console\Event\ConsoleTerminateEvent;
 use Symfony\Component\Console\Exception\CommandNotFoundException;
 use Symfony\Component\Console\Exception\NamespaceNotFoundException;
@@ -42,6 +43,8 @@ use Symfony\Component\Console\Terminal;
 use Symfony\Component\Console\Tester\ApplicationTester;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
 use Symfony\Component\EventDispatcher\EventDispatcher;
+use Symfony\Component\EventDispatcher\EventDispatcherInterface;
+use Symfony\Component\EventDispatcher\EventSubscriberInterface;
 use Symfony\Component\Process\Process;
 
 class ApplicationTest extends TestCase
@@ -1172,6 +1175,25 @@ class ApplicationTest extends TestCase
         $this->assertTrue($passedRightValue, '-> exit code 1 was passed in the console.terminate event');
     }
 
+    /**
+     * @testWith [-1]
+     *           [-32000]
+     */
+    public function testRunReturnsExitCodeOneForNegativeExceptionCode($exceptionCode)
+    {
+        $exception = new \Exception('', $exceptionCode);
+
+        $application = $this->getMockBuilder(Application::class)->setMethods(['doRun'])->getMock();
+        $application->setAutoExit(false);
+        $application->expects($this->once())
+            ->method('doRun')
+            ->willThrowException($exception);
+
+        $exitCode = $application->run(new ArrayInput([]), new NullOutput());
+
+        $this->assertSame(1, $exitCode, '->run() returns exit code 1 when exception code is '.$exceptionCode);
+    }
+
     public function testAddingOptionWithDuplicateShortcut()
     {
         $this->expectException(\LogicException::class);
@@ -1843,7 +1865,27 @@ class ApplicationTest extends TestCase
     /**
      * @requires extension pcntl
      */
-    public function testSignal()
+    public function testSignalListenerNotCalledByDefault()
+    {
+        $command = new SignableCommand(false);
+
+        $dispatcherCalled = false;
+        $dispatcher = new EventDispatcher();
+        $dispatcher->addListener('console.signal', function () use (&$dispatcherCalled) {
+            $dispatcherCalled = true;
+        });
+
+        $application = $this->createSignalableApplication($command, $dispatcher);
+
+        $this->assertSame(0, $application->run(new ArrayInput(['signal'])));
+        $this->assertFalse($command->signaled);
+        $this->assertFalse($dispatcherCalled);
+    }
+
+    /**
+     * @requires extension pcntl
+     */
+    public function testSignalListener()
     {
         $command = new SignableCommand();
 
@@ -1853,29 +1895,81 @@ class ApplicationTest extends TestCase
             $dispatcherCalled = true;
         });
 
-        $application = new Application();
-        $application->setAutoExit(false);
-        $application->setDispatcher($dispatcher);
-        $application->setSignalsToDispatchEvent(\SIGALRM);
-        $application->add(new LazyCommand('signal', [], '', false, function () use ($command) { return $command; }, true));
+        $application = $this->createSignalableApplication($command, $dispatcher);
 
-        $this->assertFalse($command->signaled);
-        $this->assertFalse($dispatcherCalled);
+        $this->assertSame(1, $application->run(new ArrayInput(['signal'])));
+        $this->assertTrue($dispatcherCalled);
+        $this->assertTrue($command->signaled);
+    }
+
+    /**
+     * @requires extension pcntl
+     */
+    public function testSignalSubscriberNotCalledByDefault()
+    {
+        $command = new BaseSignableCommand(false);
+
+        $subscriber = new SignalEventSubscriber();
+        $dispatcher = new EventDispatcher();
+        $dispatcher->addSubscriber($subscriber);
+
+        $application = $this->createSignalableApplication($command, $dispatcher);
 
         $this->assertSame(0, $application->run(new ArrayInput(['signal'])));
-        $this->assertFalse($command->signaled);
-        $this->assertFalse($dispatcherCalled);
+        $this->assertFalse($subscriber->signaled);
+    }
+
+    /**
+     * @requires extension pcntl
+     */
+    public function testSignalSubscriber()
+    {
+        $command = new BaseSignableCommand();
+
+        $subscriber1 = new SignalEventSubscriber();
+        $subscriber2 = new SignalEventSubscriber();
+
+        $dispatcher = new EventDispatcher();
+        $dispatcher->addSubscriber($subscriber1);
+        $dispatcher->addSubscriber($subscriber2);
+
+        $application = $this->createSignalableApplication($command, $dispatcher);
 
-        $command->loop = 100000;
-        pcntl_alarm(1);
         $this->assertSame(1, $application->run(new ArrayInput(['signal'])));
-        $this->assertTrue($command->signaled);
-        $this->assertTrue($dispatcherCalled);
+        $this->assertTrue($subscriber1->signaled);
+        $this->assertTrue($subscriber2->signaled);
+    }
+
+    /**
+     * @requires extension pcntl
+     */
+    public function testSetSignalsToDispatchEvent()
+    {
+        if (!\defined('SIGUSR1')) {
+            $this->markTestSkipped('SIGUSR1 not available');
+        }
+
+        $command = new BaseSignableCommand();
+
+        $subscriber = new SignalEventSubscriber();
+
+        $dispatcher = new EventDispatcher();
+        $dispatcher->addSubscriber($subscriber);
+
+        $application = $this->createSignalableApplication($command, $dispatcher);
+        $application->setSignalsToDispatchEvent(\SIGUSR2);
+        $this->assertSame(0, $application->run(new ArrayInput(['signal'])));
+        $this->assertFalse($subscriber->signaled);
+
+        $application = $this->createSignalableApplication($command, $dispatcher);
+        $application->setSignalsToDispatchEvent(\SIGUSR1);
+        $this->assertSame(1, $application->run(new ArrayInput(['signal'])));
+        $this->assertTrue($subscriber->signaled);
     }
 
     public function testSignalableCommandInterfaceWithoutSignals()
     {
-        $command = new SignableCommand();
+        $command = new SignableCommand(false);
 
         $dispatcher = new EventDispatcher();
         $application = new Application();
@@ -1885,6 +1979,25 @@ class ApplicationTest extends TestCase
         $this->assertSame(0, $application->run(new ArrayInput(['signal'])));
     }
 
+    public function testSignalableCommandHandlerCalledAfterEventListener()
+    {
+        if (!\defined('SIGUSR1')) {
+            $this->markTestSkipped('SIGUSR1 not available');
+        }
+
+        $command = new SignableCommand();
+
+        $subscriber = new SignalEventSubscriber();
+
+        $dispatcher = new EventDispatcher();
+        $dispatcher->addSubscriber($subscriber);
+
+        $application = $this->createSignalableApplication($command, $dispatcher);
+        $application->setSignalsToDispatchEvent(\SIGUSR1);
+        $this->assertSame(1, $application->run(new ArrayInput(['signal'])));
+        $this->assertSame([SignalEventSubscriber::class, SignableCommand::class], $command->signalHandlers);
+    }
+
     /**
      * @group tty
      */
@@ -1917,6 +2030,18 @@ class ApplicationTest extends TestCase
 
         $this->assertSame($previousSttyMode, $sttyMode);
     }
+
+    private function createSignalableApplication(Command $command, ?EventDispatcherInterface $dispatcher): Application
+    {
+        $application = new Application();
+        $application->setAutoExit(false);
+        if ($dispatcher) {
+            $application->setDispatcher($dispatcher);
+        }
+        $application->add(new LazyCommand('signal', [], '', false, function () use ($command) { return $command; }, true));
+
+        return $application;
+    }
 }
 
 class CustomApplication extends Application
@@ -1971,25 +2096,27 @@ class DisabledCommand extends Command
     }
 }
 
-class SignableCommand extends Command implements SignalableCommandInterface
+class BaseSignableCommand extends Command
 {
     public $signaled = false;
-    public $loop = 100;
+    public $signalHandlers = [];
+    public $loop = 1000;
+    private $emitsSignal;
 
     protected static $defaultName = 'signal';
 
-    public function getSubscribedSignals(): array
+    public function __construct(bool $emitsSignal = true)
     {
-        return SignalRegistry::isSupported() ? [\SIGALRM] : [];
-    }
-
-    public function handleSignal(int $signal): void
-    {
-        $this->signaled = true;
+        parent::__construct();
+        $this->emitsSignal = $emitsSignal;
     }
 
     protected function execute(InputInterface $input, OutputInterface $output): int
     {
+        if ($this->emitsSignal) {
+            posix_kill(posix_getpid(), SIGUSR1);
+        }
+
         for ($i = 0; $i < $this->loop; ++$i) {
             usleep(100);
             if ($this->signaled) {
@@ -2000,3 +2127,36 @@ class SignableCommand extends Command implements SignalableCommandInterface
         return 0;
     }
 }
+
+class SignableCommand extends BaseSignableCommand implements SignalableCommandInterface
+{
+    protected static $defaultName = 'signal';
+
+    public function getSubscribedSignals(): array
+    {
+        return SignalRegistry::isSupported() ? [\SIGUSR1] : [];
+    }
+
+    public function handleSignal(int $signal): void
+    {
+        $this->signaled = true;
+        $this->signalHandlers[] = __CLASS__;
+    }
+}
+
+class SignalEventSubscriber implements EventSubscriberInterface
+{
+    public $signaled = false;
+
+    public function onSignal(ConsoleSignalEvent $event): void
+    {
+        $this->signaled = true;
+        $event->getCommand()->signaled = true;
+        $event->getCommand()->signalHandlers[] = __CLASS__;
+    }
+
+    public static function getSubscribedEvents(): array
+    {
+        return ['console.signal' => 'onSignal'];
+    }
+}
