@@ -210,7 +210,7 @@ class ProgressBarTest extends TestCase
 
         // max in construct, explicit format before
         $bar = new ProgressBar($output = $this->getOutputStream(), 10, 0);
-        $bar->setFormat('normal');
+        $bar->setFormat(ProgressBar::FORMAT_NORMAL);
         $bar->start();
         $bar->advance(10);
         $bar->finish();
@@ -220,7 +220,7 @@ class ProgressBarTest extends TestCase
 
         // max in start, explicit format before
         $bar = new ProgressBar($output = $this->getOutputStream(), 0, 0);
-        $bar->setFormat('normal');
+        $bar->setFormat(ProgressBar::FORMAT_NORMAL);
         $bar->start(10);
         $bar->advance(10);
         $bar->finish();
@@ -535,7 +535,7 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
     public function testRedrawFrequencyIsAtLeastOneIfSmallerOneGiven()
     {
         $bar = new ProgressBar($output = $this->getOutputStream(), 0, 0);
-        $bar->setRedrawFrequency(0.9);
+        $bar->setRedrawFrequency(0);
         $bar->start();
         $bar->advance();
 
@@ -812,8 +812,10 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
         $this->assertEquals(
             ">---------------------------\nfoobar".
             $this->generateOutput("=========>------------------\nfoobar").
-            "\x1B[1A\x1B[1G\x1B[2K".
-            $this->generateOutput("============================\nfoobar"),
+            "\x1B[1G\x1B[2K\x1B[1A".
+            $this->generateOutput('').
+            $this->generateOutput('============================').
+            "\nfoobar",
             stream_get_contents($output->getStream())
         );
     }
@@ -881,7 +883,7 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
     public function testSetFormat()
     {
         $bar = new ProgressBar($output = $this->getOutputStream(), 0, 0);
-        $bar->setFormat('normal');
+        $bar->setFormat(ProgressBar::FORMAT_NORMAL);
         $bar->start();
         rewind($output->getStream());
         $this->assertEquals(
@@ -890,7 +892,7 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
         );
 
         $bar = new ProgressBar($output = $this->getOutputStream(), 10, 0);
-        $bar->setFormat('normal');
+        $bar->setFormat(ProgressBar::FORMAT_NORMAL);
         $bar->start();
         rewind($output->getStream());
         $this->assertEquals(
@@ -899,6 +901,21 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
         );
     }
 
+    public function testUnicode()
+    {
+        $bar = new ProgressBar($output = $this->getOutputStream(), 10, 0);
+        ProgressBar::setFormatDefinition('test', '%current%/%max% [%bar%] %percent:3s%% %message% Fruitcake marzipan toffee. Cupcake gummi bears tart dessert ice cream chupa chups cupcake chocolate bar sesame snaps. Croissant halvah cookie jujubes powder macaroon. Fruitcake bear claw bonbon jelly beans oat cake pie muffin Fruitcake marzipan toffee.');
+        $bar->setFormat('test');
+        $bar->setProgressCharacter('💧');
+        $bar->start();
+        rewind($output->getStream());
+        $this->assertStringContainsString(
+            ' 0/10 [💧]   0%',
+            stream_get_contents($output->getStream())
+        );
+        $bar->finish();
+    }
+
     /**
      * @dataProvider provideFormat
      */
@@ -968,7 +985,7 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
     {
         $count = substr_count($expected, "\n");
 
-        return ($count ? sprintf("\x1B[%dA\x1B[1G\x1b[2K", $count) : "\x1B[1G\x1B[2K").$expected;
+        return ($count ? str_repeat("\x1B[1G\x1b[2K\x1B[1A", $count) : '')."\x1B[1G\x1B[2K".$expected;
     }
 
     public function testBarWidthWithMultilineFormat()
@@ -1018,14 +1035,14 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
         $bar->setRedrawFrequency(4); // disable step based redraws
         $bar->start();
 
-        $bar->setProgress(1); // No treshold hit, no redraw
+        $bar->setProgress(1); // No threshold hit, no redraw
         $bar->maxSecondsBetweenRedraws(2);
         sleep(1);
         $bar->setProgress(2); // Still no redraw because it takes 2 seconds for a redraw
         sleep(1);
         $bar->setProgress(3); // 1+1 = 2 -> redraw finally
         $bar->setProgress(4); // step based redraw freq hit, redraw even without sleep
-        $bar->setProgress(5); // No treshold hit, no redraw
+        $bar->setProgress(5); // No threshold hit, no redraw
         $bar->maxSecondsBetweenRedraws(3);
         sleep(2);
         $bar->setProgress(6); // No redraw even though 2 seconds passed. Throttling has priority
@@ -1056,7 +1073,7 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
         $bar->setProgress(3); // 1 second passed but we changed threshold, should not draw
         sleep(1);
         $bar->setProgress(4); // 1+1 seconds = 2 seconds passed which conforms threshold, draw
-        $bar->setProgress(5); // No treshold hit, no redraw
+        $bar->setProgress(5); // No threshold hit, no redraw
 
         rewind($output->getStream());
         $this->assertEquals(
@@ -1080,4 +1097,58 @@ And, as in uffish thought he stood, The Jabberwock, with eyes of flame, Came whi
             stream_get_contents($output->getStream())
         );
     }
+
+    public function testMultiLineFormatIsFullyCleared()
+    {
+        $bar = new ProgressBar($output = $this->getOutputStream(), 3);
+        $bar->setFormat("%current%/%max%\n%message%\nFoo");
+
+        $bar->setMessage('1234567890');
+        $bar->start();
+        $bar->display();
+
+        $bar->setMessage('ABC');
+        $bar->advance();
+        $bar->display();
+
+        $bar->setMessage('A');
+        $bar->advance();
+        $bar->display();
+
+        $bar->finish();
+
+        rewind($output->getStream());
+        $this->assertEquals(
+            "0/3\n1234567890\nFoo".
+            $this->generateOutput("1/3\nABC\nFoo").
+            $this->generateOutput("2/3\nA\nFoo").
+            $this->generateOutput("3/3\nA\nFoo"),
+            stream_get_contents($output->getStream())
+        );
+    }
+
+    public function testMultiLineFormatIsFullyCorrectlyWithManuallyCleanup()
+    {
+        ProgressBar::setFormatDefinition('normal_nomax', "[%bar%]\n%message%");
+        $bar = new ProgressBar($output = $this->getOutputStream());
+        $bar->setMessage('Processing "foobar"...');
+        $bar->start();
+        $bar->clear();
+        $output->writeln('Foo!');
+        $bar->display();
+        $bar->finish();
+
+        rewind($output->getStream());
+        $this->assertEquals(
+            "[>---------------------------]\n".
+            'Processing "foobar"...'.
+            "\x1B[1G\x1B[2K\x1B[1A".
+            $this->generateOutput('').
+            'Foo!'.\PHP_EOL.
+            $this->generateOutput('[--->------------------------]').
+            "\nProcessing \"foobar\"...".
+            $this->generateOutput("[----->----------------------]\nProcessing \"foobar\"..."),
+            stream_get_contents($output->getStream())
+        );
+    }
 }
