@@ -119,11 +119,11 @@ TABLE
                 $books,
                 'compact',
 <<<'TABLE'
- ISBN          Title                    Author           
- 99921-58-10-7 Divine Comedy            Dante Alighieri  
- 9971-5-0210-0 A Tale of Two Cities     Charles Dickens  
- 960-425-059-0 The Lord of the Rings    J. R. R. Tolkien 
- 80-902734-1-6 And Then There Were None Agatha Christie  
+ISBN          Title                    Author           
+99921-58-10-7 Divine Comedy            Dante Alighieri  
+9971-5-0210-0 A Tale of Two Cities     Charles Dickens  
+960-425-059-0 The Lord of the Rings    J. R. R. Tolkien 
+80-902734-1-6 And Then There Were None Agatha Christie  
 
 TABLE
             ],
@@ -616,8 +616,8 @@ TABLE
                 'default',
                 <<<'TABLE'
 +-------+------------+
-[39;49m| [39;49m[37;41mDont break[39;49m[39;49m         |[39;49m
-[39;49m| [39;49m[37;41mhere[39;49m               |
+[37;41m| [39;49m[37;41mDont break[39;49m[37;41m         |[39;49m
+[37;41m| here[39;49m               |
 +-------+------------+
 [39;49m| foo   | [39;49m[37;41mDont break[39;49m[39;49m |[39;49m
 [39;49m| bar   | [39;49m[37;41mhere[39;49m       |
@@ -1285,6 +1285,26 @@ TABLE;
 | 80-902734-1-6 | And Then There Were None | Agatha Christie  |
 +---------------+--------- Page 1/2 -------+------------------+
 
+TABLE
+                ,
+                true,
+           ],
+            'header contains multiple lines' => [
+                'Multiline'."\n".'header'."\n".'here',
+                'footer',
+                'default',
+                <<<'TABLE'
++---------------+---- Multiline
+header
+here -+------------------+
+| ISBN          | Title                    | Author           |
++---------------+--------------------------+------------------+
+| 99921-58-10-7 | Divine Comedy            | Dante Alighieri  |
+| 9971-5-0210-0 | A Tale of Two Cities     | Charles Dickens  |
+| 960-425-059-0 | The Lord of the Rings    | J. R. R. Tolkien |
+| 80-902734-1-6 | And Then There Were None | Agatha Christie  |
++---------------+---------- footer --------+------------------+
+
 TABLE
             ],
             [
@@ -1365,6 +1385,41 @@ TABLE;
 |               | ities |            |                 |
 +---------------+-------+------------+-----------------+
 
+TABLE;
+
+        $this->assertEquals($expected, $this->getOutputContent($output));
+    }
+
+    public function testColumnMaxWidthsHeaders()
+    {
+        $table = new Table($output = $this->getOutputStream());
+        $table
+            ->setHeaders([
+                [
+                    'Publication',
+                    'Very long header with a lot of information',
+                ],
+            ])
+            ->setRows([
+                [
+                    '1954',
+                    'The Lord of the Rings, by J.R.R. Tolkien',
+                ],
+            ])
+            ->setColumnMaxWidth(1, 30);
+
+        $table->render();
+
+        $expected =
+            <<<TABLE
++-------------+--------------------------------+
+| Publication | Very long header with a lot of |
+|             | information                    |
++-------------+--------------------------------+
+| 1954        | The Lord of the Rings, by J.R. |
+|             | R. Tolkien                     |
++-------------+--------------------------------+
+
 TABLE;
 
         $this->assertEquals($expected, $this->getOutputContent($output));
@@ -1540,6 +1595,31 @@ EOTXT;
 |                 |                 | nsectetur       |
 +-----------------+-----------------+-----------------+
 
+TABLE;
+
+        $this->assertSame($expected, $this->getOutputContent($output));
+    }
+
+    public function testWithHyperlinkAndMaxWidth()
+    {
+        $table = new Table($output = $this->getOutputStream(true));
+        $table
+            ->setRows([
+                ['<href=Lorem>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor</>'],
+            ])
+        ;
+        $table->setColumnMaxWidth(0, 20);
+        $table->render();
+
+        $expected =
+            <<<TABLE
++----------------------+
+| \033]8;;Lorem\033\\Lorem ipsum dolor si\033]8;;\033\\ |
+| \033]8;;Lorem\033\\t amet, consectetur \033]8;;\033\\ |
+| \033]8;;Lorem\033\\adipiscing elit, sed\033]8;;\033\\ |
+| \033]8;;Lorem\033\\do eiusmod tempor\033]8;;\033\\    |
++----------------------+
+
 TABLE;
 
         $this->assertSame($expected, $this->getOutputContent($output));
