@@ -67,9 +67,29 @@ class CommandTesterTest extends TestCase
         $this->assertEquals('foo'.\PHP_EOL, $this->tester->getDisplay(), '->getDisplay() returns the display of the last execution');
     }
 
+    public function testGetDisplayWithoutCallingExecuteBefore()
+    {
+        $tester = new CommandTester(new Command());
+
+        $this->expectException(\RuntimeException::class);
+        $this->expectExceptionMessage('Output not initialized');
+
+        $tester->getDisplay();
+    }
+
     public function testGetStatusCode()
     {
-        $this->assertSame(0, $this->tester->getStatusCode(), '->getStatusCode() returns the status code');
+        $this->tester->assertCommandIsSuccessful('->getStatusCode() returns the status code');
+    }
+
+    public function testGetStatusCodeWithoutCallingExecuteBefore()
+    {
+        $tester = new CommandTester(new Command());
+
+        $this->expectException(\RuntimeException::class);
+        $this->expectExceptionMessage('Status code not initialized');
+
+        $tester->getStatusCode();
     }
 
     public function testCommandFromApplication()
@@ -109,7 +129,7 @@ class CommandTesterTest extends TestCase
         $tester->setInputs(['Bobby', 'Fine', 'France']);
         $tester->execute([]);
 
-        $this->assertEquals(0, $tester->getStatusCode());
+        $tester->assertCommandIsSuccessful();
         $this->assertEquals(implode('', $questions), $tester->getDisplay(true));
     }
 
@@ -134,7 +154,7 @@ class CommandTesterTest extends TestCase
         $tester->setInputs(['', '', '']);
         $tester->execute([]);
 
-        $this->assertEquals(0, $tester->getStatusCode());
+        $tester->assertCommandIsSuccessful();
         $this->assertEquals(implode('', $questions), $tester->getDisplay(true));
     }
 
@@ -207,7 +227,7 @@ class CommandTesterTest extends TestCase
         $tester->setInputs(['Bobby', 'Fine', 'France']);
         $tester->execute([]);
 
-        $this->assertEquals(0, $tester->getStatusCode());
+        $tester->assertCommandIsSuccessful();
     }
 
     public function testErrorOutput()
@@ -217,8 +237,7 @@ class CommandTesterTest extends TestCase
         $command->addArgument('foo');
         $command->setCode(function ($input, $output) {
             $output->getErrorOutput()->write('foo');
-        }
-        );
+        });
 
         $tester = new CommandTester($command);
         $tester->execute(
