@@ -86,7 +86,7 @@ class ResolveClassPassTest extends TestCase
     public function testAmbiguousChildDefinition()
     {
         $this->expectException(InvalidArgumentException::class);
-        $this->expectExceptionMessage('Service definition "App\Foo\Child" has a parent but no class, and its name looks like a FQCN. Either the class is missing or you want to inherit it from the parent service. To resolve this ambiguity, please rename this service to a non-FQCN (e.g. using dots), or create the missing class.');
+        $this->expectExceptionMessage('Service definition "App\Foo\Child" has a parent but no class, and its name looks like an FQCN. Either the class is missing or you want to inherit it from the parent service. To resolve this ambiguity, please rename this service to a non-FQCN (e.g. using dots), or create the missing class.');
         $container = new ContainerBuilder();
         $container->register('App\Foo', null);
         $container->setDefinition('App\Foo\Child', new ChildDefinition('App\Foo'));
