@@ -14,10 +14,14 @@ namespace Symfony\Component\Form\Tests\Extension\Core\DataMapper;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\EventDispatcher\EventDispatcher;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
+use Symfony\Component\Form\Extension\Core\DataAccessor\PropertyPathAccessor;
 use Symfony\Component\Form\Extension\Core\DataMapper\DataMapper;
+use Symfony\Component\Form\Extension\Core\Type\DateType;
 use Symfony\Component\Form\Form;
 use Symfony\Component\Form\FormConfigBuilder;
+use Symfony\Component\Form\FormFactoryBuilder;
 use Symfony\Component\Form\Tests\Fixtures\TypehintedPropertiesCar;
+use Symfony\Component\PropertyAccess\PropertyAccess;
 use Symfony\Component\PropertyAccess\PropertyPath;
 
 class DataMapperTest extends TestCase
@@ -50,7 +54,7 @@ class DataMapperTest extends TestCase
         $config->setPropertyPath($propertyPath);
         $form = new Form($config);
 
-        $this->mapper->mapDataToForms($car, [$form]);
+        $this->mapper->mapDataToForms($car, new \ArrayIterator([$form]));
 
         self::assertSame($engine, $form->getData());
     }
@@ -68,7 +72,7 @@ class DataMapperTest extends TestCase
         $config->setPropertyPath($propertyPath);
         $form = new Form($config);
 
-        $this->mapper->mapDataToForms($car, [$form]);
+        $this->mapper->mapDataToForms($car, new \ArrayIterator([$form]));
 
         self::assertNotSame($engine, $form->getData());
         self::assertEquals($engine, $form->getData());
@@ -84,7 +88,7 @@ class DataMapperTest extends TestCase
 
         self::assertNull($form->getPropertyPath());
 
-        $this->mapper->mapDataToForms($car, [$form]);
+        $this->mapper->mapDataToForms($car, new \ArrayIterator([$form]));
 
         self::assertNull($form->getData());
     }
@@ -101,7 +105,7 @@ class DataMapperTest extends TestCase
         $config->setPropertyPath($propertyPath);
         $form = new Form($config);
 
-        $this->mapper->mapDataToForms($car, [$form]);
+        $this->mapper->mapDataToForms($car, new \ArrayIterator([$form]));
 
         self::assertNull($form->getData());
     }
@@ -117,7 +121,7 @@ class DataMapperTest extends TestCase
         $car = new TypehintedPropertiesCar();
         $car->engine = 'BMW';
 
-        $this->mapper->mapDataToForms($car, [$engineForm, $colorForm]);
+        $this->mapper->mapDataToForms($car, new \ArrayIterator([$engineForm, $colorForm]));
 
         self::assertSame($car->engine, $engineForm->getData());
         self::assertNull($colorForm->getData());
@@ -135,7 +139,7 @@ class DataMapperTest extends TestCase
 
         $form = new Form($config);
 
-        $this->mapper->mapDataToForms(null, [$form]);
+        $this->mapper->mapDataToForms(null, new \ArrayIterator([$form]));
 
         self::assertSame($default, $form->getData());
     }
@@ -152,7 +156,7 @@ class DataMapperTest extends TestCase
 
         $form = new Form($config);
 
-        $this->mapper->mapDataToForms([], [$form]);
+        $this->mapper->mapDataToForms([], new \ArrayIterator([$form]));
 
         self::assertSame($default, $form->getData());
     }
@@ -171,7 +175,7 @@ class DataMapperTest extends TestCase
         $config->setData($engine);
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertEquals($engine, $car->engine);
         self::assertNotSame($engine, $car->engine);
@@ -190,7 +194,7 @@ class DataMapperTest extends TestCase
         $config->setData($engine);
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame($engine, $car->engine);
     }
@@ -209,7 +213,7 @@ class DataMapperTest extends TestCase
 
         $car->engine = 'Rolls-Royce';
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame('Rolls-Royce', $car->engine);
     }
@@ -229,7 +233,7 @@ class DataMapperTest extends TestCase
         $config->setMapped(false);
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame($initialEngine, $car->engine);
     }
@@ -248,7 +252,7 @@ class DataMapperTest extends TestCase
         $config->setData($engine);
         $form = new Form($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame($initialEngine, $car->engine);
     }
@@ -266,7 +270,7 @@ class DataMapperTest extends TestCase
         $config->setData(null);
         $form = new Form($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame($initialEngine, $car->engine);
     }
@@ -285,7 +289,7 @@ class DataMapperTest extends TestCase
         $config->setData($engine);
         $form = new NotSynchronizedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame($initialEngine, $car->engine);
     }
@@ -305,7 +309,7 @@ class DataMapperTest extends TestCase
         $config->setDisabled(true);
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame($initialEngine, $car->engine);
     }
@@ -320,7 +324,7 @@ class DataMapperTest extends TestCase
         $config->setData('BMW');
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $car);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $car);
 
         self::assertSame('BMW', $car->engine);
     }
@@ -342,7 +346,7 @@ class DataMapperTest extends TestCase
         $config->setData($publishedAt);
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $article);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $article);
 
         self::assertSame($publishedAtValue, $article['publishedAt']);
     }
@@ -367,7 +371,7 @@ class DataMapperTest extends TestCase
         ]);
         $form = new Form($config);
 
-        $this->mapper->mapDataToForms($person, [$form]);
+        $this->mapper->mapDataToForms($person, new \ArrayIterator([$form]));
 
         self::assertSame($initialName, $form->getData());
     }
@@ -384,10 +388,37 @@ class DataMapperTest extends TestCase
         $config->setData('Jane Doe');
         $form = new SubmittedForm($config);
 
-        $this->mapper->mapFormsToData([$form], $person);
+        $this->mapper->mapFormsToData(new \ArrayIterator([$form]), $person);
 
         self::assertSame('Jane Doe', $person->myName());
     }
+
+    public function testMapFormsToDataMapsDateTimeInstanceToArrayIfNotSetBefore()
+    {
+        $propertyAccessor = PropertyAccess::createPropertyAccessorBuilder()
+            ->enableExceptionOnInvalidIndex()
+            ->getPropertyAccessor();
+        $propertyAccessor = PropertyAccess::createPropertyAccessorBuilder()
+            ->enableExceptionOnInvalidIndex()
+            ->getPropertyAccessor();
+        $form = (new FormFactoryBuilder())->getFormFactory()->createBuilder()
+            ->setDataMapper(new DataMapper(new PropertyPathAccessor($propertyAccessor)))
+            ->add('date', DateType::class, [
+                'auto_initialize' => false,
+                'format' => 'dd/MM/yyyy',
+                'html5' => false,
+                'model_timezone' => 'UTC',
+                'view_timezone' => 'UTC',
+                'widget' => 'single_text',
+            ])
+            ->getForm();
+
+        $form->submit([
+            'date' => '04/08/2022',
+        ]);
+
+        $this->assertEquals(['date' => new \DateTime('2022-08-04', new \DateTimeZone('UTC'))], $form->getData());
+    }
 }
 
 class SubmittedForm extends Form
