@@ -147,7 +147,7 @@ class PdoSessionHandlerTest extends TestCase
 
     public function testReadLockedConvertsStreamToString()
     {
-        if (filter_var(ini_get('session.use_strict_mode'), \FILTER_VALIDATE_BOOLEAN)) {
+        if (filter_var(\ini_get('session.use_strict_mode'), \FILTER_VALIDATE_BOOLEAN)) {
             $this->markTestSkipped('Strict mode needs no locking for new sessions.');
         }
 
@@ -156,7 +156,7 @@ class PdoSessionHandlerTest extends TestCase
         $insertStmt = $this->createMock(\PDOStatement::class);
 
         $pdo->prepareResult = function ($statement) use ($selectStmt, $insertStmt) {
-            return 0 === strpos($statement, 'INSERT') ? $insertStmt : $selectStmt;
+            return str_starts_with($statement, 'INSERT') ? $insertStmt : $selectStmt;
         };
 
         $content = 'foobar';
@@ -332,6 +332,8 @@ class PdoSessionHandlerTest extends TestCase
     public function provideUrlDsnPairs()
     {
         yield ['mysql://localhost/test', 'mysql:host=localhost;dbname=test;'];
+        yield ['mysql://localhost/test?charset=utf8mb4', 'mysql:charset=utf8mb4;host=localhost;dbname=test;'];
+        yield ['mysql://localhost/test?unix_socket=socket.sock&charset=utf8mb4', 'mysql:charset=utf8mb4;unix_socket=socket.sock;dbname=test;'];
         yield ['mysql://localhost:56/test', 'mysql:host=localhost;port=56;dbname=test;'];
         yield ['mysql2://root:pwd@localhost/test', 'mysql:host=localhost;dbname=test;', 'root', 'pwd'];
         yield ['postgres://localhost/test', 'pgsql:host=localhost;dbname=test;'];
@@ -371,6 +373,10 @@ class MockPdo extends \PDO
         $this->errorMode = null !== $errorMode ?: \PDO::ERRMODE_EXCEPTION;
     }
 
+    /**
+     * @return mixed
+     */
+    #[\ReturnTypeWillChange]
     public function getAttribute($attribute)
     {
         if (\PDO::ATTR_ERRMODE === $attribute) {
@@ -384,6 +390,10 @@ class MockPdo extends \PDO
         return parent::getAttribute($attribute);
     }
 
+    /**
+     * @return false|\PDOStatement
+     */
+    #[\ReturnTypeWillChange]
     public function prepare($statement, $driverOptions = [])
     {
         return \is_callable($this->prepareResult)
@@ -391,11 +401,13 @@ class MockPdo extends \PDO
             : $this->prepareResult;
     }
 
-    public function beginTransaction()
+    public function beginTransaction(): bool
     {
+        return true;
     }
 
-    public function rollBack()
+    public function rollBack(): bool
     {
+        return true;
     }
 }
