@@ -22,7 +22,7 @@ class RedisSessionHandlerTest extends AbstractRedisSessionHandlerTestCase
     protected function createRedisClient(string $host): object
     {
         $client = new \Redis();
-        $client->connect($host);
+        $client->connect(...explode(':', $host));
 
         return $client;
     }
