@@ -32,7 +32,7 @@ return [
         ],
         'AUD' => [
             0 => 'A$',
-            1 => 'Австралия доллары',
+            1 => 'Аустралия доллары',
         ],
         'AWG' => [
             0 => 'AWG',
@@ -576,7 +576,7 @@ return [
         ],
         'TWD' => [
             0 => 'NT$',
-            1 => 'Жаңа Тайван доллары',
+            1 => 'Жаңа Тайвань доллары',
         ],
         'TZS' => [
             0 => 'TZS',
@@ -624,7 +624,7 @@ return [
         ],
         'XAF' => [
             0 => 'FCFA',
-            1 => 'КФА ВЕАС франкі',
+            1 => 'Орталық Африканың КФА франкі',
         ],
         'XCD' => [
             0 => 'EC$',
@@ -632,7 +632,7 @@ return [
         ],
         'XOF' => [
             0 => 'F CFA',
-            1 => 'КФА ВСЕАО франкі',
+            1 => 'Батыс Африканың КФА франкі',
         ],
         'XPF' => [
             0 => 'CFPF',
