@@ -15,15 +15,18 @@ return [
         'alt' => 'দাক্ষিণাত্য আল্টাই',
         'am' => 'আমহাৰিক',
         'an' => 'আৰ্গোনিজ',
+        'ann' => 'অ’ব’ল’',
         'anp' => 'আঙ্গিকা',
         'ar' => 'আৰবী',
         'arn' => 'মাপুচে',
         'arp' => 'আৰাপাহো',
+        'ars' => 'নাজডি আৰবী',
         'as' => 'অসমীয়া',
         'asa' => 'আছু',
         'ast' => 'এষ্টুৰীয়',
+        'atj' => 'আতিকামেক',
         'av' => 'আভেৰিক',
-        'awa' => 'আৱাধি',
+        'awa' => 'অৱধী',
         'ay' => 'আয়মাৰা',
         'az' => 'আজেৰবাইজানী',
         'ba' => 'বাছখিৰ',
@@ -46,6 +49,7 @@ return [
         'bug' => 'বগিনীজ',
         'byn' => 'ব্লিন',
         'ca' => 'কাতালান',
+        'cay' => 'কায়ুগা',
         'ccp' => 'চাক্‌মা',
         'ce' => 'চেচেন',
         'ceb' => 'চিবুৱানো',
@@ -54,12 +58,21 @@ return [
         'chk' => 'চুকিজ',
         'chm' => 'মাৰি',
         'cho' => 'চোক্টাউ',
+        'chp' => 'চিপেউয়ান',
         'chr' => 'চেৰোকি',
         'chy' => 'চাইয়েন',
         'ckb' => 'চেণ্ট্ৰেল কুৰ্ডিচ',
+        'clc' => 'চিলক’টিন',
         'co' => 'কোৰ্ছিকান',
+        'crg' => 'মিচিফ',
+        'crj' => 'দাক্ষিণাত্য ইষ্ট ক্ৰী',
+        'crk' => 'প্লেইনছ ক্ৰী',
+        'crl' => 'নৰ্দাৰ্ন ইষ্ট ক্ৰী',
+        'crm' => 'মুজ ক্ৰী',
+        'crr' => 'কেৰ’লিনা আলগংকিয়ান',
         'crs' => 'ছেছেলৱা ক্ৰিওল ফ্ৰেন্স',
         'cs' => 'চেক',
+        'csw' => 'স্বাম্পী ক্ৰী',
         'cu' => 'চাৰ্চ শ্লেভিক',
         'cv' => 'চুভাচ',
         'cy' => 'ৱেলচ',
@@ -96,6 +109,8 @@ return [
         'fo' => 'ফাৰোইজ',
         'fon' => 'ফ’ন',
         'fr' => 'ফ্ৰেন্স',
+        'frc' => 'কেজ’ন ফৰাছী',
+        'frr' => 'নৰ্দাৰ্ন ফ্ৰিছিয়ান',
         'fur' => 'ফ্ৰিউলিয়ান',
         'fy' => 'ৱেষ্টাৰ্ণ ফ্ৰিছিয়ান',
         'ga' => 'আইৰিচ',
@@ -112,7 +127,9 @@ return [
         'gv' => 'মেংক্স',
         'gwi' => 'জিউইচিন',
         'ha' => 'হাউছা',
+        'hai' => 'হেইডা',
         'haw' => 'হাৱাই',
+        'hax' => 'দাক্ষিণাত্যৰ হাইডা',
         'he' => 'হিব্ৰু',
         'hi' => 'হিন্দী',
         'hil' => 'হিলিগায়নোন',
@@ -122,6 +139,7 @@ return [
         'ht' => 'হেইটিয়ান ক্ৰিয়ল',
         'hu' => 'হাঙ্গেৰিয়ান',
         'hup' => 'হুপা',
+        'hur' => 'হেলকোমেলেম',
         'hy' => 'আৰ্মেনীয়',
         'hz' => 'হেৰেৰো',
         'ia' => 'ইণ্টাৰলিংগুৱা',
@@ -130,6 +148,7 @@ return [
         'id' => 'ইণ্ডোনেচিয়',
         'ig' => 'ইগ্বো',
         'ii' => 'ছিচুৱান ই',
+        'ikt' => 'ৱেষ্টাৰ্ণ কানাডিয়ান ইনক্টিটুট',
         'ilo' => 'ইলোকো',
         'inh' => 'ইংগুচ',
         'io' => 'ইডো',
@@ -151,6 +170,7 @@ return [
         'kde' => 'মাকোণ্ড',
         'kea' => 'কাবুভেৰ্ডিয়ানু',
         'kfo' => 'কোৰো',
+        'kgp' => 'কেইংগাং',
         'kha' => 'খাচি',
         'khq' => 'কোয়াৰ চিনি',
         'ki' => 'কিকুয়ু',
@@ -177,6 +197,7 @@ return [
         'kum' => 'কুমিক',
         'kv' => 'কোমি',
         'kw' => 'কোৰ্নিচ',
+        'kwk' => 'ক্বাকৱালা',
         'ky' => 'কিৰ্গিজ',
         'la' => 'লেটিন',
         'lad' => 'লাডিনো',
@@ -185,11 +206,14 @@ return [
         'lez' => 'লেজঘিয়ান',
         'lg' => 'গান্দা',
         'li' => 'লিম্বুৰ্গিচ',
+        'lil' => 'লিল্লোৱেট',
         'lkt' => 'লাকোটা',
         'ln' => 'লিংগালা',
         'lo' => 'লাও',
+        'lou' => 'লুইজিয়ানা কেৰ’ল',
         'loz' => 'লোজি',
         'lrc' => 'উদীচ্য লুৰি',
+        'lsm' => 'চামিয়া',
         'lt' => 'লিথুৱানিয়ান',
         'lu' => 'লুবা-কাটাংগা',
         'lua' => 'লুবা-লুলুৱা',
@@ -218,6 +242,7 @@ return [
         'ml' => 'মালায়ালম',
         'mn' => 'মংগোলীয়',
         'mni' => 'মণিপুৰী',
+        'moe' => 'ইন্নু-আইমুন',
         'moh' => 'মোহোক',
         'mos' => 'মোছি',
         'mr' => 'মাৰাঠী',
@@ -254,6 +279,11 @@ return [
         'ny' => 'ন্যাঞ্জা',
         'nyn' => 'ন্যানকোল',
         'oc' => 'অ’চিটান',
+        'ojb' => 'নৰ্থ-ৱেষ্টাৰ্ণ অজিবৱা',
+        'ojc' => 'চেন্ট্ৰেক অজিবৱা',
+        'ojs' => 'অ’জি-ক্ৰী',
+        'ojw' => 'ৱেষ্টাৰ্ণ অজিবৱা',
+        'oka' => 'অ’কানাগান',
         'om' => 'ওৰোমো',
         'or' => 'ওড়িয়া',
         'os' => 'ওছেটিক',
@@ -263,7 +293,9 @@ return [
         'pap' => 'পাপিয়ামেণ্টো',
         'pau' => 'পালাউৱান',
         'pcm' => 'নাইজেৰিয়ান পিজিন',
+        'pis' => 'পিজিন',
         'pl' => 'প’লিচ',
+        'pqm' => 'মালিছীট-পাছামাকু’ডী',
         'prg' => 'প্ৰুছিয়ান',
         'ps' => 'পুস্ত',
         'pt' => 'পৰ্তুগীজ',
@@ -300,6 +332,7 @@ return [
         'si' => 'সিংহলা',
         'sk' => 'শ্লোভাক',
         'sl' => 'শ্লোভেনিয়ান',
+        'slh' => 'দাক্ষিণাত্যৰ লুছুটচীড',
         'sm' => 'ছামোন',
         'sma' => 'দাক্ষিণাত্য ছামি',
         'smj' => 'লুলে ছামি',
@@ -314,6 +347,7 @@ return [
         'ss' => 'স্বাতি',
         'ssy' => 'ছাহো',
         'st' => 'দাক্ষিণাত্য ছোথো',
+        'str' => 'ষ্ট্ৰেইটছ ছেলিশ্ব',
         'su' => 'ছুণ্ডানীজ',
         'suk' => 'ছুকুমা',
         'sv' => 'ছুইডিচ',
@@ -321,23 +355,29 @@ return [
         'swb' => 'কোমোৰিয়ান',
         'syr' => 'চিৰিয়াক',
         'ta' => 'তামিল',
+        'tce' => 'দাক্ষিণাত্যৰ টুটচ’ন',
         'te' => 'তেলুগু',
         'tem' => 'টিম্নে',
         'teo' => 'তেছো',
         'tet' => 'তেতুম',
         'tg' => 'তাজিক',
+        'tgx' => 'টেগিশ্ব',
         'th' => 'থাই',
+        'tht' => 'টাহলটান',
         'ti' => 'টিগৰিনিয়া',
         'tig' => 'তাইগ্ৰে',
         'tk' => 'তুৰ্কমেন',
         'tlh' => 'ক্লিংগন',
+        'tli' => 'লিংগিট',
         'tn' => 'ছোৱানা',
         'to' => 'টোঙ্গান',
+        'tok' => 'ট’কি প’না',
         'tpi' => 'টোক পিছিন',
         'tr' => 'তুৰ্কী',
         'trv' => 'তাৰোকো',
         'ts' => 'ছোঙ্গা',
         'tt' => 'তাতাৰ',
+        'ttm' => 'নৰ্দাৰ্ন টুটচ’ন',
         'tum' => 'তুম্বুকা',
         'tvl' => 'টুভালু',
         'twq' => 'টাছাৱাক',
@@ -360,6 +400,7 @@ return [
         'wal' => 'ওলেইটা',
         'war' => 'ৱাৰে',
         'wo' => 'ৱোলাফ',
+        'wuu' => 'ৱু চাইনিজ',
         'xal' => 'কাল্মিক',
         'xh' => 'হোছা',
         'xog' => 'ছোগা',
@@ -367,6 +408,7 @@ return [
         'ybb' => 'য়েম্বা',
         'yi' => 'ইদ্দিছ',
         'yo' => 'ইউৰুবা',
+        'yrl' => 'হিংগাটো',
         'yue' => 'কেণ্টোনীজ',
         'zgh' => 'ষ্টেণ্ডাৰ্ড মোৰোক্কান তামাজাইট',
         'zh' => 'চীনা',
