@@ -23,6 +23,7 @@ return [
         'am' => 'Amharic',
         'an' => 'Aragonese',
         'ang' => 'Old English',
+        'ann' => 'Obolo',
         'anp' => 'Angika',
         'ar' => 'Arabic',
         'arc' => 'Aramaic',
@@ -60,6 +61,7 @@ return [
         'bfd' => 'Bafut',
         'bfq' => 'Badaga',
         'bg' => 'Bulgarian',
+        'bgc' => 'Haryanvi',
         'bgn' => 'Western Balochi',
         'bho' => 'Bhojpuri',
         'bi' => 'Bislama',
@@ -67,7 +69,7 @@ return [
         'bin' => 'Bini',
         'bjn' => 'Banjar',
         'bkm' => 'Kom',
-        'bla' => 'Siksika',
+        'bla' => 'Siksiká',
         'blt' => 'Tai Dam',
         'bm' => 'Bambara',
         'bn' => 'Bangla',
@@ -166,7 +168,7 @@ return [
         'fa' => 'Persian',
         'fan' => 'Fang',
         'fat' => 'Fanti',
-        'ff' => 'Fulah',
+        'ff' => 'Fula',
         'fi' => 'Finnish',
         'fil' => 'Filipino',
         'fit' => 'Tornedalen Finnish',
@@ -314,7 +316,7 @@ return [
         'la' => 'Latin',
         'lad' => 'Ladino',
         'lag' => 'Langi',
-        'lah' => 'Lahnda',
+        'lah' => 'Western Panjabi',
         'lam' => 'Lamba',
         'lb' => 'Luxembourgish',
         'lez' => 'Lezghian',
@@ -332,6 +334,7 @@ return [
         'lou' => 'Louisiana Creole',
         'loz' => 'Lozi',
         'lrc' => 'Northern Luri',
+        'lsm' => 'Saamia',
         'lt' => 'Lithuanian',
         'ltg' => 'Latgalian',
         'lu' => 'Luba-Katanga',
@@ -445,11 +448,12 @@ return [
         'pfl' => 'Palatine German',
         'phn' => 'Phoenician',
         'pi' => 'Pali',
+        'pis' => 'Pijin',
         'pl' => 'Polish',
         'pms' => 'Piedmontese',
         'pnt' => 'Pontic',
         'pon' => 'Pohnpeian',
-        'pqm' => 'Malecite',
+        'pqm' => 'Maliseet-Passamaquoddy',
         'prg' => 'Prussian',
         'pro' => 'Old Provençal',
         'ps' => 'Pashto',
@@ -477,7 +481,7 @@ return [
         'rwk' => 'Rwa',
         'sa' => 'Sanskrit',
         'sad' => 'Sandawe',
-        'sah' => 'Sakha',
+        'sah' => 'Yakut',
         'sam' => 'Samaritan Aramaic',
         'saq' => 'Samburu',
         'sas' => 'Sasak',
@@ -565,6 +569,7 @@ return [
         'tn' => 'Tswana',
         'to' => 'Tongan',
         'tog' => 'Nyasa Tonga',
+        'tok' => 'Toki Pona',
         'tpi' => 'Tok Pisin',
         'tr' => 'Turkish',
         'tru' => 'Turoyo',
